package de.szut.lf8_starter.project.action;

import de.szut.lf8_starter.project.ProjectEntity;
import de.szut.lf8_starter.project.ProjectMapper;
import de.szut.lf8_starter.project.ProjectService;
import de.szut.lf8_starter.project.dto.GetProjectDto;
import de.szut.lf8_starter.project.dto.UpdateProjectDto;
import jakarta.validation.Valid;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.Optional;

@RestController
@RequestMapping(value = "/projects")
public class UpdateProjectAction {
    private final ProjectService projectService;
    private final ProjectMapper projectMapper;

    public UpdateProjectAction(ProjectService projectService, ProjectMapper mappingService) {
        this.projectService = projectService;
        this.projectMapper = mappingService;
    }

    @PutMapping("/{id}")
    public ResponseEntity<GetProjectDto> updateSupplier(@PathVariable Long id, @Valid @RequestBody UpdateProjectDto updateProjectDto) {
        Optional<ProjectEntity> project = this.projectService.findById(id);

        if (project.isEmpty()) {
            return new ResponseEntity<>(HttpStatus.NOT_FOUND);
        }

        ProjectEntity updatedProject = this.projectMapper.mapUpdateDtoToEntity(updateProjectDto, project.get());
        this.projectService.update(updatedProject);

        return new ResponseEntity<>(this.projectMapper.mapToGetDto(updatedProject), HttpStatus.OK);
    }
}
